@@ -6,15 +6,16 @@ import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
 /**
  * 
- * @author "Giancarlo Panichi" <a
- *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
+ * @author Giancarlo Panichi
+ *
  * 
  */
 public class CloneTabularResourceSession implements Serializable {
 
 	private static final long serialVersionUID = -1896235499708614266L;
 
-	protected TRId trId;
+	private TRId trId;
+	private TRId trIdClone;
 	
 	public CloneTabularResourceSession(){
 		
@@ -22,6 +23,7 @@ public class CloneTabularResourceSession implements Serializable {
 	
 	public CloneTabularResourceSession(TRId trId){
 		this.trId=trId;
+		this.trIdClone=null;
 	}
 
 	public TRId getTrId() {
@@ -32,9 +34,20 @@ public class CloneTabularResourceSession implements Serializable {
 		this.trId = trId;
 	}
 
-	@Override
-	public String toString() {
-		return "CloneTabularResourceSession [trId=" + trId + "]";
+	
+	public TRId getTrIdClone() {
+		return trIdClone;
 	}
 
+	public void setTrIdClone(TRId trIdClone) {
+		this.trIdClone = trIdClone;
+	}
+
+	@Override
+	public String toString() {
+		return "CloneTabularResourceSession [trId=" + trId + ", trIdClone="
+				+ trIdClone + "]";
+	}
+
+	
 }
